# Credits

Credits to [Khalil Misbah](https://www.linkedin.com/in/khalil-misbah/) for the original design of the geemap logo.

![logo](https://raw.githubusercontent.com/gee-community/geemap/master/docs/assets/logo.png)
